@@ -1,8 +1,18 @@
+# small wrapper around this commonly used try-catch
+.safe <- function(code, on_error = NULL) {
+  if (isTRUE(getOption("easystats_errors", FALSE)) && is.null(on_error)) {
+    code
+  } else {
+    tryCatch(code, error = function(e) on_error)
+  }
+}
+
+
 # remove values from vector
 .remove_values <- function(x, values) {
-  remove <- x %in% values
-  if (any(remove)) {
-    x <- x[!remove]
+  to_remove <- x %in% values
+  if (any(to_remove)) {
+    x <- x[!to_remove]
   }
   x
 }
@@ -15,11 +25,10 @@
 }
 
 
-
 # is string empty?
 .is_empty_string <- function(x) {
   x <- x[!is.na(x)]
-  length(x) == 0 || all(nchar(x) == 0)
+  length(x) == 0 || all(nchar(x) == 0) # nolint
 }
 
 
@@ -33,14 +42,26 @@
 }
 
 
+.remove_namespace_from_string <- function(x) {
+  # remove namespace prefixes
+  if (grepl("::", x, fixed = TRUE)) {
+    # Here's a regular expression pattern in R that removes any word
+    # followed by two colons from a string: This pattern matches a word
+    # boundary (\\b), followed by one or more word characters (\\w+),
+    # followed by two colons (::)
+    x <- gsub("\\b\\w+::", "\\2", x)
+  }
+  x
+}
+
+
 # checks if a brms-models is a multi-membership-model
 .is_multi_membership <- function(x) {
-  if (inherits(x, "brmsfit")) {
-    re <- find_random(x, split_nested = TRUE, flatten = TRUE)
-    any(grepl("^(mmc|mm)\\(", re))
-  } else {
+  if (!inherits(x, "brmsfit")) {
     return(FALSE)
   }
+  re <- find_random(x, split_nested = TRUE, flatten = TRUE)
+  any(grepl("^(mmc|mm)\\(", re))
 }
 
 
@@ -97,18 +118,18 @@
 # if there are any chars left, these come from further terms that come after
 # random effects...
 .formula_empty_after_random_effect <- function(f) {
-  nchar(gsub("(~|\\+|\\*|-|/|:)", "", gsub(" ", "", gsub("\\((.*)\\)", "", f)))) == 0
+  nchar(gsub("(~|\\+|\\*|-|/|:)", "", gsub(" ", "", gsub("\\((.*)\\)", "", f), fixed = TRUE))) == 0 # nolint
 }
 
 
-
 # extract random effects from formula
-.get_model_random <- function(f, split_nested = FALSE, model) {
+.get_model_random <- function(f, model, split_nested = FALSE) {
   is_special <- inherits(
     model,
     c(
       "MCMCglmm", "gee", "LORgee", "mixor", "clmm2", "felm", "feis", "bife",
-      "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm", "glmm"
+      "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm", "glmm",
+      "glmgee"
     )
   )
 
@@ -120,24 +141,30 @@
 
   if (is_special && is_empty_object(re)) {
     re <- all.vars(f[[2L]])
-    if (length(re) > 1) {
+    if (length(re) > 1L) {
       re <- as.list(re)
       split_nested <- FALSE
     }
   } else {
-    re <- trim_ws(substring(re, max(gregexpr(pattern = "\\|", re)[[1]]) + 1))
+    re <- trim_ws(substring(re, max(gregexpr(pattern = "|", re, fixed = TRUE)[[1]]) + 1))
   }
 
   # check for multi-membership models
   if (inherits(model, "brmsfit")) {
     if (grepl("mm\\((.*)\\)", re)) {
-      re <- trim_ws(unlist(strsplit(gsub("mm\\((.*)\\)", "\\1", re), ",")))
+      # extract variables
+      re <- clean_names(re)
+    } else if (grepl("gr\\((.*)\\)", re)) {
+      # remove namespace prefixes
+      re <- .remove_namespace_from_string(re)
+      # extract random effects term
+      re <- trim_ws(gsub("gr\\((\\w+)(,.*|)\\)", "\\1", re))
     }
   }
 
   if (split_nested) {
     # remove parenthesis for nested models
-    re <- unique(unlist(strsplit(re, "\\:")))
+    re <- unique(unlist(strsplit(re, ":", fixed = TRUE)))
 
     # nested random effects, e.g. g1 / g2 / g3, deparse to "g0:(g1:g2)".
     # when we split at ":", we have "g0", "(g1" and "g2)". In such cases,
@@ -167,17 +194,14 @@
 }
 
 
-
 # in case we need the random effects terms as formula (symbol),
 # not as character string, then call this functions instead of
 # .get_model_random()
 .get_group_factor <- function(x, f) {
   if (is.list(f)) {
-    f <- lapply(f, function(.x) {
-      .get_model_random(.x, split_nested = TRUE, x)
-    })
+    f <- lapply(f, .get_model_random, model = x, split_nested = TRUE)
   } else {
-    f <- .get_model_random(f, split_nested = TRUE, x)
+    f <- .get_model_random(f, model = x, split_nested = TRUE)
   }
 
   if (is.null(f)) {
@@ -185,7 +209,7 @@
   }
 
   if (is.list(f)) {
-    f <- lapply(f, function(i) sapply(i, as.symbol))
+    f <- lapply(f, sapply, as.symbol)
   } else {
     f <- sapply(f, as.symbol)
   }
@@ -194,10 +218,8 @@
 }
 
 
-
 # helper to access model components ----------------
 
-
 .all_elements <- function() {
   c(
     "conditional", "conditional1", "conditional2", "conditional3", "precision",
@@ -206,7 +228,8 @@
     "sigma", "nu", "tau", "correlation", "slopes", "cluster", "extra", "scale",
     "marginal", "alpha", "beta", "survival", "infrequent_purchase", "auxiliary",
     "mix", "shiftprop", "phi", "ndt", "hu", "xi", "coi", "zoi", "aux", "dist",
-    "selection", "outcome", "time_dummies", "sigma_random", "beta_random", "car"
+    "selection", "outcome", "time_dummies", "sigma_random", "beta_random", "car",
+    "nominal"
   )
 }
 
@@ -235,12 +258,15 @@
   random_parameters <- c("random", "zero_inflated_random", "sigma_random", "beta_random", "car")
 
   # conditional component
-  conditional_component <- setdiff(elements, c(auxiliary_parameters, zero_inflated_component, "smooth_terms", "nonlinear"))
+  conditional_component <- setdiff(
+    elements,
+    c(auxiliary_parameters, zero_inflated_component, "smooth_terms", "nonlinear")
+  )
 
   # location parameters
   location_parameters <- switch(effects,
-    "fixed" = setdiff(elements, c(auxiliary_parameters, random_parameters)),
-    "random" = intersect(setdiff(elements, auxiliary_parameters), random_parameters),
+    fixed = setdiff(elements, c(auxiliary_parameters, random_parameters)),
+    random = intersect(setdiff(elements, auxiliary_parameters), random_parameters),
     setdiff(elements, auxiliary_parameters)
   )
 
@@ -254,7 +280,6 @@
     return(auxiliary_parameters)
   }
 
-
   elements <- switch(effects,
     all = elements,
     fixed = elements[!elements %in% random_parameters],
@@ -274,40 +299,6 @@
 }
 
 
-
-
-# checks if a mixed model fit is singular or not. Need own function,
-# because lme4::isSingular() does not work with glmmTMB
-.is_singular <- function(x, vals, tolerance = 1e-5) {
-  check_if_installed("lme4", reason = "to compute variances for mixed models")
-
-  tryCatch(
-    {
-      if (inherits(x, c("glmmTMB", "clmm", "cpglmm"))) {
-        is_si <- any(sapply(vals$vc, function(.x) any(abs(diag(.x)) < tolerance)))
-      } else if (inherits(x, "merMod")) {
-        theta <- lme4::getME(x, "theta")
-        diag.element <- lme4::getME(x, "lower") == 0
-        is_si <- any(abs(theta[diag.element]) < tolerance)
-      } else if (inherits(x, "MixMod")) {
-        vc <- diag(x$D)
-        is_si <- any(sapply(vc, function(.x) any(abs(.x) < tolerance)))
-      } else if (inherits(x, "lme")) {
-        is_si <- any(abs(stats::na.omit(as.numeric(diag(vals$vc))) < tolerance))
-      } else {
-        is_si <- FALSE
-      }
-
-      is_si
-    },
-    error = function(x) {
-      FALSE
-    }
-  )
-}
-
-
-
 # Filter parameters from Stan-model fits
 .filter_pars <- function(l, parameters = NULL, is_mv = NULL) {
   if (!is.null(parameters)) {
@@ -328,28 +319,25 @@
 }
 
 
-
 .filter_pars_univariate <- function(l, parameters) {
   lapply(l, function(component) {
-    unlist(unname(sapply(
+    unlist(sapply(
       parameters,
       function(pattern) {
-        component[grepl(pattern = pattern, x = component, perl = TRUE)]
+        grep(pattern = pattern, x = component, perl = TRUE, value = TRUE)
       },
       simplify = FALSE
-    )))
+    ), use.names = FALSE)
   })
 }
 
 
-
 # remove column
 .remove_column <- function(data, variables) {
   data[, -which(colnames(data) %in% variables), drop = FALSE]
 }
 
 
-
 .grep_smoothers <- function(x) {
   startsWith(x, "s(") |
     startsWith(x, "ti(") |
@@ -367,7 +355,6 @@
 }
 
 
-
 .grep_zi_smoothers <- function(x) {
   grepl("^(s\\.\\d\\()", x, perl = TRUE) |
     grepl("^(gam::s\\.\\d\\()", x, perl = TRUE) |
@@ -375,7 +362,6 @@
 }
 
 
-
 .grep_non_smoothers <- function(x) {
   grepl("^(?!(s\\())", x, perl = TRUE) &
     # this one captures smoothers in zi- or mv-models from gam
@@ -396,9 +382,8 @@
 }
 
 
-
 # .split_formula <- function(f) {
-#   rhs <- if (length(f) > 2)
+#   rhs <- if (length(f) > 2L)
 #     f[[3L]]
 #   else
 #     f[[2L]]
@@ -421,56 +406,38 @@
 # }
 
 
-
 .gam_family <- function(x) {
-  faminfo <- tryCatch(
-    {
-      stats::family(x)
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  faminfo <- .safe(stats::family(x))
 
   # try to set manually, if not found otherwise
   if (is.null(faminfo)) {
-    faminfo <- tryCatch(
-      {
-        x$family
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    faminfo <- .safe(x$family)
   }
 
   faminfo
 }
 
 
-
 # for models with zero-inflation component, return
 # required component of model-summary
 .filter_component <- function(dat, component) {
   switch(component,
-    "cond" = ,
-    "conditional" = dat[dat$Component == "conditional", , drop = FALSE],
-    "zi" = ,
-    "zero_inflated" = dat[dat$Component == "zero_inflated", , drop = FALSE],
-    "dispersion" = dat[dat$Component == "dispersion", , drop = FALSE],
-    "smooth_terms" = dat[dat$Component == "smooth_terms", , drop = FALSE],
-    "ip" = ,
-    "infrequent_purchase" = dat[dat$Component == "infrequent_purchase", , drop = FALSE],
-    "auxiliary" = dat[dat$Component == "auxiliary", , drop = FALSE],
-    "distributional" = dat[dat$Component == "distributional", , drop = FALSE],
-    "sigma" = dat[dat$Component == "sigma", , drop = FALSE],
+    cond = ,
+    conditional = dat[dat$Component == "conditional", , drop = FALSE],
+    zi = ,
+    zero_inflated = dat[dat$Component == "zero_inflated", , drop = FALSE],
+    dispersion = dat[dat$Component == "dispersion", , drop = FALSE],
+    smooth_terms = dat[dat$Component == "smooth_terms", , drop = FALSE],
+    ip = ,
+    infrequent_purchase = dat[dat$Component == "infrequent_purchase", , drop = FALSE],
+    auxiliary = dat[dat$Component == "auxiliary", , drop = FALSE],
+    distributional = dat[dat$Component == "distributional", , drop = FALSE],
+    sigma = dat[dat$Component == "sigma", , drop = FALSE],
     dat
   )
 }
 
 
-
-
 #' @keywords internal
 .gather <- function(x,
                     names_to = "key",
@@ -497,7 +464,6 @@
 }
 
 
-
 .is_baysian_emmeans <- function(x) {
   if (inherits(x, "emm_list")) {
     x <- x[[1]]
@@ -507,7 +473,6 @@
 }
 
 
-
 .is_bayesian_model <- function(x) {
   inherits(x, c(
     "brmsfit", "stanfit", "MCMCglmm", "stanreg",
@@ -519,7 +484,6 @@
 }
 
 
-
 # safe conversion from factor to numeric
 .factor_to_numeric <- function(x, lowest = NULL) {
   if (is.data.frame(x)) {
@@ -546,6 +510,13 @@
     }
     x <- droplevels(x)
     levels(x) <- 1:nlevels(x)
+  } else if (is.unsorted(levels(x))) {
+    # for numeric factors, we need to check the order of levels
+    x_inverse <- rep(NA_real_, length(x))
+    for (i in 1:nlevels(x)) {
+      x_inverse[x == levels(x)[i]] <- as.numeric(levels(x)[nlevels(x) - i + 1])
+    }
+    x <- factor(x_inverse)
   }
 
   out <- as.numeric(as.character(x))
@@ -559,9 +530,6 @@
 }
 
 
-
-
-
 ## copied from lme4::findbars() -----------------------
 
 
@@ -571,13 +539,12 @@
   if (attr(stats::terms(frml), "intercept") != 0) {
     newtrms <- c("1", newtrms)
   }
-  stats::as.formula(paste("~(", paste(vapply(newtrms, function(trm) {
+  stats::as.formula(paste("~(", paste(vapply(newtrms, function(trm) { # nolint
     paste0(trm, "|", deparse(term[[3]]))
   }, ""), collapse = ")+("), ")"))[[2]]
 }
 
 
-
 .expandDoubleVerts <- function(term) {
   if (!is.name(term) && is.language(term)) {
     if (term[[1]] == as.name("(")) {
@@ -596,7 +563,6 @@
 }
 
 
-
 .findbars <- function(term) {
   fb <- function(term) {
     if (is.name(term) || !is.language(term)) {
@@ -617,7 +583,7 @@
 
   expandSlash <- function(bb) {
     makeInteraction <- function(x) {
-      if (length(x) < 2) {
+      if (length(x) < 2L) {
         return(x)
       }
       trm1 <- makeInteraction(x[[1]])
@@ -633,15 +599,14 @@
         return(x)
       }
       if (x[[1]] != as.name("/")) {
-        stop("unparseable formula for grouping factor", call. = FALSE)
+        format_error("unparseable formula for grouping factor")
       }
       list(slashTerms(x[[2]]), slashTerms(x[[3]]))
     }
-    if (!is.list(bb)) {
-      expandSlash(list(bb))
-    } else {
+    if (is.list(bb)) {
       unlist(lapply(bb, function(x) {
-        if (length(x) > 2 && is.list(trms <- slashTerms(x[[3]]))) {
+        trms <- slashTerms(x[[3]])
+        if (length(x) > 2 && is.list(trms)) {
           lapply(unlist(makeInteraction(trms)), function(trm) {
             substitute(foo | bar, list(foo = x[[2]], bar = trm))
           })
@@ -649,6 +614,8 @@
           x
         }
       }))
+    } else {
+      expandSlash(list(bb))
     }
   }
   modterm <- .expandDoubleVerts(if (methods::is(term, "formula")) {
@@ -660,8 +627,6 @@
 }
 
 
-
-
 ## copied from lme4::nobars() -----------------------
 
 
@@ -681,7 +646,6 @@
 }
 
 
-
 .nobars_ <- function(term) {
   if (!(any(c("|", "||") %in% all.names(term)))) {
     return(term)
@@ -721,12 +685,9 @@
 }
 
 
-
 .isBar <- function(term) {
-  if (is.call(term)) {
-    if ((term[[1]] == as.name("|")) || (term[[1]] == as.name("||"))) {
-      return(TRUE)
-    }
+  if (is.call(term) && ((term[[1]] == as.name("|") || term[[1]] == as.name("||")))) {
+    return(TRUE)
   }
   FALSE
 }
@@ -744,7 +705,6 @@
 }
 
 
-
 # classify emmeans objects -------------
 
 
@@ -784,7 +744,11 @@ is.emmean <- function(x) {
   c_ <- is.emmeans.contrast(x)
   t_ <- is.emmeans.trend(x)
 
-  ifelse(c_, "contrasts",
-    ifelse(t_, "emtrends", "emmeans")
-  )
+  if (isTRUE(c_)) {
+    "contrasts"
+  } else if (isTRUE(t_)) {
+    "emtrends"
+  } else {
+    "emmeans"
+  }
 }
